%DBIx::FullTextSearch::TestConfig::Config = (
                                              'dsn' => 'dbi:mysql:tsweb',
                                              'password' => 'max88next',
                                              'user' => 'tsweb'
                                            );
1;
